@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -605,7 +602,6 @@ arp_transmit(arp_session_t * session, arp_client_t * client,
 
     /* fill in the ethernet header */
     switch (if_link_arptype(client->if_p)) {
-    default:
     case ARPHRD_ETHER:
 	{
 	    struct ether_header *	eh_p;
@@ -669,6 +665,12 @@ arp_transmit(arp_session_t * session, arp_client_t * client,
 	    size = sizeof(*fh_p) + sizeof(*farp);
 	}
 	break;
+    default:
+	snprintf(client->errmsg, sizeof(client->errmsg),
+		 "arp_transmit(%s): interface hardware type not yet known", 
+		 if_name(client->if_p));
+	return (0);
+	break;
     }
 
     status = bpf_write(session->bpf_fd, txbuf, size);
@@ -795,7 +797,8 @@ arp_client_init(arp_session_t * session, interface_t * if_p)
     arp_client_t *		client;
     struct firewire_address	fw_addr;
 
-    switch (if_link_type(if_p)) {
+    switch (if_ift_type(if_p)) {
+    case IFT_L2VLAN:
     case IFT_ETHER:
 	break;
     case IFT_IEEE1394:
