@@ -321,7 +321,7 @@ make_dhcp_reply(struct dhcp * reply, int pkt_size,
     return (NULL);
 }
 
-static __inline__ struct dhcp * 
+static struct dhcp * 
 make_dhcp_nak(struct dhcp * reply, int pkt_size, 
 	      struct in_addr server_id, dhcp_msgtype_t * msg_p, 
 	      char * nak_msg, struct dhcp * request, 
@@ -394,7 +394,7 @@ S_ipinuse(void * arg, struct in_addr ip)
 #define DHCPD_CREATOR		"dhcpd"
 
 static char *
-S_get_hostname(void * hostname_opt, int hostname_opt_len, struct in_addr iaddr)
+S_get_hostname(void * hostname_opt, int hostname_opt_len)
 {
 
     if (hostname_opt && hostname_opt_len > 0) {
@@ -598,8 +598,8 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
     void *		hostname_opt = NULL;
     int			hostname_opt_len = 0;
     char *		hostname = NULL;
-    char *		hwstr = NULL;
-    char *		idstr = NULL;
+    u_char *		hwstr = NULL;
+    u_char *		idstr = NULL;
     struct in_addr	iaddr;
     dhcp_lease_t	lease = 0;
     dhcp_time_secs_t	lease_time_expiry = 0;
@@ -613,6 +613,8 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
     struct dhcp *	reply = NULL;
     dhcp_msgtype_t	reply_msgtype = dhcp_msgtype_none_e;
     struct dhcp *	rq = request->pkt;
+    u_char		scratch_idstr[128];
+    u_char		scratch_hwstr[sizeof(rq->dp_chaddr) * 3];
     id 			subnet = nil;
     dhcp_lease_t *	suggested_lease = NULL;
     dhcp_cstate_t	state = dhcp_cstate_none_e;
@@ -635,9 +637,19 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
 	cid_type = rq->dp_htype;
 	cid_len = rq->dp_hlen;
     }
-    idstr = identifierToString(cid_type, cid, cid_len);
-    if (cid_type == 0)
-	hwstr = identifierToString(rq->dp_htype, rq->dp_chaddr, rq->dp_hlen);
+    idstr = identifierToStringWithBuffer(cid_type, cid, cid_len,
+					 scratch_idstr, sizeof(scratch_idstr));
+    if (idstr == NULL) {
+	goto no_reply;
+    }
+    if (cid_type == 0) {
+	hwstr = identifierToStringWithBuffer(rq->dp_htype, rq->dp_chaddr, 
+					     rq->dp_hlen, scratch_hwstr,
+					     sizeof(scratch_hwstr));
+	if (hwstr == NULL) {
+	    goto no_reply;
+	}
+    }
     else {
 	hwstr = idstr;
     }
@@ -863,6 +875,12 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
 		      S_remove_host(&entry);
 		      binding = dhcp_binding_none_e;
 		  }
+		  if (detect_other_dhcp_server) {
+		      my_log(LOG_INFO, 
+			     "dhcpd: detected another DHCP server %s, exiting",
+			     inet_ntoa(*server_id));
+		      exit(2);
+		  }
 		  goto no_reply;
 	      }
 	      
@@ -923,13 +941,13 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
 		      if (hostname)
 			  free(hostname);
 		      hostname = S_get_hostname(hostname_opt, 
-						hostname_opt_len, iaddr);
+						hostname_opt_len);
 		      ni_set_prop(&entry->pl, NIPROP_NAME, hostname, 
 				  &modified);
 		  }
 		  else if (hostname == NULL) {
 		      hostname = S_get_hostname(hostname_opt, 
-						hostname_opt_len, iaddr);
+						hostname_opt_len);
 		  }
 	      }
 	      if (binding != dhcp_binding_none_e) {
@@ -1041,7 +1059,7 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
 			  free(hostname);
 		      }
 		      hostname = S_get_hostname(hostname_opt, 
-						hostname_opt_len, iaddr);
+						hostname_opt_len);
 		      ni_set_prop(&entry->pl, NIPROP_NAME, hostname, 
 				  &modified);
 		  }
@@ -1181,6 +1199,19 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
 	if (S_commit_mods() == FALSE)
 	    goto no_reply;
     }
+    { /* check the seconds field */
+	u_int16_t	secs;
+	
+	secs = (u_int16_t)ntohs(rq->dp_secs);
+	if (secs < reply_threshold_seconds) {
+	    if (debug) {
+		printf("rp->dp_secs %d < threshold %d\n",
+		       secs, reply_threshold_seconds);
+	    }
+	    goto no_reply;
+	}
+	
+    }
     if (reply) {
 	if (reply_msgtype == dhcp_msgtype_ack_e || 
 	    reply_msgtype == dhcp_msgtype_offer_e) {
@@ -1254,9 +1285,9 @@ dhcp_request(request_t * request, dhcp_msgtype_t msgtype,
 	free(bootfile);
     if (hostname)
 	free(hostname);
-    if (idstr)
+    if (idstr != scratch_idstr)
 	free(idstr);
-    if (hwstr && hwstr != idstr)
+    if (hwstr != NULL && hwstr != idstr && hwstr != scratch_hwstr)
 	free(hwstr);
     return;
 }
